@@ -1,6 +1,6 @@
 # Decode raw bytes JSON into an R list object.
 decode_json <- function(raw) {
-  obj <- json_to_list(rawToChar(raw))
+  obj <- json_to_list(raw_to_utf8(raw))
   return(obj)
 }
 
